@@ -12,13 +12,19 @@ import dotenv
 from .build import detect_unity, build_def, unity, build_data
 from . import steps, config
 
-VERSION = "v0.0.2"
+VERSION = "v0.0.3"
 
 
-@dataclass
 class ToriiCliContext:
-    cfg: config.ToriiCliConfig
-    project_path: str
+    def __init__(self, cfg: config.ToriiCliConfig, project_path: str) -> None:
+        self.cfg = cfg
+
+        # if the project path is not absolute, we need to make it so, as
+        # Unity expects it to be absolute
+        if not path.isabs(project_path):
+            project_path = path.abspath(project_path)
+
+        self.project_path = project_path
 
 
 pass_ctx = click.make_pass_decorator(ToriiCliContext)
@@ -48,11 +54,6 @@ def toriicli(ctx, project_path):
         if cfg is None:
             raise SystemExit(1)
 
-        # if the project path is not absolute, we need to make it so, as
-        # Unity expects it to be absolute
-        if not path.isabs(project_path):
-            project_path = path.abspath(project_path)
-
         ctx.obj = ToriiCliContext(cfg, cfg.actual_project_dir or project_path)
 
 
